---
name: Bug fix
about: Submit a PR to help us improve
title: "[Bug fix]"
labels: ''
assignees: ''

---


**Describe what bug you fixed**
A clear and concise description of the bug you fixed. If it is related to any issue, provide the issue number will be very appreciated.


**Checklist**

- [ ] I've already read the [contributing guide](../../CONTRIBUTING.md).
- [ ] I've run all tests and make sure all exists test cases are passed.
- [ ] I've make sure this PR works with `Sanic-18.12` and `Python-3.5`.
